Enum sp_runtime::MultiSigner [−][src]
Public key for any known crypto algorithm.
Variants
Ed25519(Public)An Ed25519 identity.
Tuple Fields of Ed25519
0: PublicSr25519(Public)An Sr25519 identity.
Tuple Fields of Sr25519
0: PublicEcdsa(Public)An SECP256k1/ECDSA identity (actually, the Blake2 hash of the compressed pub key).
Tuple Fields of Ecdsa
0: PublicTrait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
type AccountId = AccountId32
type AccountId = AccountId32
The account ID that this can be transformed into.
Transform into an account.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
NOTE: This implementations is required by SimpleAddressDeterminer,
we convert the hash into some AccountId, it’s fine to use any scheme.
Convert from an instance of T to Self. This is not guaranteed to be
whatever counts as a valid instance of T and it’s up to the caller to
ensure that it makes sense. Read more