Enum sp_runtime::generic::DigestItem [−][src]
pub enum DigestItem {
PreRuntime(ConsensusEngineId, Vec<u8>),
Consensus(ConsensusEngineId, Vec<u8>),
Seal(ConsensusEngineId, Vec<u8>),
Other(Vec<u8>),
RuntimeEnvironmentUpdated,
}Expand description
Digest item that is able to encode/decode ‘system’ digest items and provide opaque access to other items.
Variants
PreRuntime(ConsensusEngineId, Vec<u8>)A pre-runtime digest.
These are messages from the consensus engine to the runtime, although the consensus engine can (and should) read them itself to avoid code and state duplication. It is erroneous for a runtime to produce these, but this is not (yet) checked.
NOTE: the runtime is not allowed to panic or fail in an on_initialize
call if an expected PreRuntime digest is not present. It is the
responsibility of a external block verifier to check this. Runtime API calls
will initialize the block without pre-runtime digests, so initialization
cannot fail when they are missing.
Tuple Fields of PreRuntime
0: ConsensusEngineId1: Vec<u8>Consensus(ConsensusEngineId, Vec<u8>)A message from the runtime to the consensus engine. This should never be generated by the native code of any consensus engine, but this is not checked (yet).
Tuple Fields of Consensus
0: ConsensusEngineId1: Vec<u8>Seal(ConsensusEngineId, Vec<u8>)Put a Seal on it. This is only used by native code, and is never seen by runtimes.
Tuple Fields of Seal
0: ConsensusEngineId1: Vec<u8>Some other thing. Unsupported and experimental.
An indication for the light clients that the runtime execution environment is updated.
Currently this is triggered when:
- Runtime code blob is changed or
heap_pagesvalue is changed.
Implementations
Returns a ‘referencing view’ for this digest item.
Returns Some if this entry is the PreRuntime entry.
Returns Some if this entry is the Consensus entry.
Returns Some if this entry is the Seal entry.
Returns the opaque data contained in the item if Some if this entry has the id given.
Returns the data contained in the item if Some if this entry has the id given, decoded
to the type provided T.
Try to match this to a Self::Seal, check id matches and decode it.
Returns None if this isn’t a seal item, the id doesn’t match or when the decoding fails.
Try to match this to a Self::Consensus, check id matches and decode it.
Returns None if this isn’t a consensus item, the id doesn’t match or
when the decoding fails.
Try to match this to a Self::PreRuntime, check id matches and decode it.
Returns None if this isn’t a pre-runtime item, the id doesn’t match or
when the decoding fails.