Enum sp_runtime::generic::DigestItemRef [−][src]
pub enum DigestItemRef<'a> {
PreRuntime(&'a ConsensusEngineId, &'a Vec<u8>),
Consensus(&'a ConsensusEngineId, &'a Vec<u8>),
Seal(&'a ConsensusEngineId, &'a Vec<u8>),
Other(&'a Vec<u8>),
RuntimeEnvironmentUpdated,
}Expand description
A ‘referencing view’ for digest item. Does not own its contents. Used by final runtime implementations for encoding/decoding its log items.
Variants
PreRuntime(&'a ConsensusEngineId, &'a Vec<u8>)A pre-runtime digest.
These are messages from the consensus engine to the runtime, although the consensus engine can (and should) read them itself to avoid code and state duplication. It is erroneous for a runtime to produce these, but this is not (yet) checked.
Tuple Fields of PreRuntime
0: &'a ConsensusEngineId1: &'a Vec<u8>Consensus(&'a ConsensusEngineId, &'a Vec<u8>)A message from the runtime to the consensus engine. This should never be generated by the native code of any consensus engine, but this is not checked (yet).
Tuple Fields of Consensus
0: &'a ConsensusEngineId1: &'a Vec<u8>Seal(&'a ConsensusEngineId, &'a Vec<u8>)Put a Seal on it. This is only used by native code, and is never seen by runtimes.
Tuple Fields of Seal
0: &'a ConsensusEngineId1: &'a Vec<u8>Any ‘non-system’ digest item, opaque to the native code.
Runtime code or heap pages updated.
Implementations
Cast this digest item into PreRuntime
Cast this digest item into Consensus
Try to match this digest item to the given opaque item identifier; if it matches, then return the opaque data it contains.
Try to match this digest item to the given opaque item identifier; if it matches, then try to cast to the given data type; if that works, return it.
Try to match this to a Self::Seal, check id matches and decode it.
Returns None if this isn’t a seal item, the id doesn’t match or when the decoding fails.
Try to match this to a Self::Consensus, check id matches and decode it.
Returns None if this isn’t a consensus item, the id doesn’t match or
when the decoding fails.
Try to match this to a Self::PreRuntime, check id matches and decode it.
Returns None if this isn’t a pre-runtime item, the id doesn’t match or
when the decoding fails.