Preamble

Enum Preamble 

pub enum Preamble<Address, Signature, ExtensionV0, ExtensionOtherVersions = InvalidVersion> {
    Bare(u8),
    Signed(Address, Signature, ExtensionV0),
    General(ExtensionVariant<ExtensionV0, ExtensionOtherVersions>),
}
A “header” for extrinsics leading up to the call itself. Determines the type of extrinsic and holds any necessary specialized data.

Bare extrinsics and signed extrinsics are extended with the transaction extension version 0, specified by the generic parameter ExtensionV0.

General extrinsics support multiple transaction extension version, specified by both ExtensionV0 and ExtensionOtherVersions, by default ExtensionOtherVersions is set to invalid version, making ExtensionV0 the only supported version. If you want to support more versions, you need to specify the ExtensionOtherVersions parameter.

Variants



Bare(u8)

An extrinsic without a signature or any extension. This means it’s either an inherent or an old-school “Unsigned” (we don’t use that terminology any more since it’s confusable with the general transaction which is without a signature but does have an extension).

NOTE: In the future, once we remove ValidateUnsigned, this will only serve Inherent extrinsics and thus can be renamed to Inherent.



Signed(Address, Signature, ExtensionV0)

An old-school transaction extrinsic which includes a signature of some hard-coded crypto. Available only on extrinsic version 4.



General(ExtensionVariant<ExtensionV0, ExtensionOtherVersions>)

A new-school transaction extrinsic which does not include a signature by default. The origin authorization, through signatures or other means, is performed by the transaction extension in this extrinsic. Available starting with extrinsic version 5.

Implementations

Source

impl<Address, Signature, ExtensionV0, ExtensionOtherVersions> Preamble<Address, Signature, ExtensionV0, ExtensionOtherVersions>

pub fn to_signed(self) -> Option<(Address, Signature, ExtensionV0)>

Returns Some if this is a signed extrinsic, together with the relevant inner fields.