CheckedExtrinsic

Struct CheckedExtrinsic 

pub struct CheckedExtrinsic<AccountId, Call, ExtensionV0, ExtensionOtherVersions = InvalidVersion> {
    pub format: ExtrinsicFormat<AccountId, ExtensionV0, ExtensionOtherVersions>,
    pub function: Call,
}
Definition of something that the external world might want to say; its existence implies that it has been checked and is good, particularly with regards to the signature.

This is typically passed into traits::Applyable::apply, which should execute CheckedExtrinsic::function, alongside all other bits and bobs.

Bare extrinsics and signed extrinsics are extended with the transaction extension version 0, specified by the generic parameter ExtensionV0.

General extrinsics support multiple transaction extension versions, specified by both ExtensionV0 and ExtensionOtherVersions, by default ExtensionOtherVersions is set to invalid version, making ExtensionV0 the only supported version. If you want to support more versions, you need to specify the ExtensionOtherVersions parameter.

Fields

format: ExtrinsicFormat<AccountId, ExtensionV0, ExtensionOtherVersions>

Who this purports to be from and the number of extrinsics have come before from the same signer, if anyone (note this is not a signature).

function: Call

The function that should be called.

Implementations

Source

impl<AccountId, Call, ExtensionV0, ExtensionOtherVersions> CheckedExtrinsic<AccountId, Call, ExtensionV0, ExtensionOtherVersions>
where Call: Dispatchable + Encode, ExtensionV0: TransactionExtension<Call>, ExtensionOtherVersions: Pipeline<Call>, <Call as Dispatchable>::RuntimeOrigin: AsTransactionAuthorizedOrigin,

pub fn extension_weight(&self) -> Weight

Returns the weight of the extension of this transaction, if present. If the transaction doesn’t use any extension, the weight returned is equal to zero.