Struct sp_runtime::generic::Header [−][src]
pub struct Header<Number: Copy + Into<U256> + TryFrom<U256>, Hash: HashT> {
pub parent_hash: Hash::Output,
pub number: Number,
pub state_root: Hash::Output,
pub extrinsics_root: Hash::Output,
pub digest: Digest,
}Expand description
Abstraction over a block header for a substrate chain.
Fields
parent_hash: Hash::OutputThe parent hash.
number: NumberThe block number.
state_root: Hash::OutputThe state trie merkle root
extrinsics_root: Hash::OutputThe merkle root of the extrinsics.
digest: DigestA chain-specific digest of data useful for light clients or referencing auxiliary data.
Implementations
A new header with the given number and default hash for all other fields.