pub struct SignedPayload<Call: Dispatchable, ExtensionV0: TransactionExtension<Call>>(/* private fields */);Expand description
A payload that has been signed for an unchecked extrinsics.
Note that the payload that we sign to produce unchecked extrinsic signature
is going to be different than the SignaturePayload - so the thing the extrinsic
actually contains.
Implementations
Sourceimpl<Call, ExtensionV0> SignedPayload<Call, ExtensionV0>
impl<Call, ExtensionV0> SignedPayload<Call, ExtensionV0>
Sourcepub fn new(
call: impl Into<CallAndMaybeEncoded<Call>>,
tx_ext: ExtensionV0,
) -> Result<Self, TransactionValidityError>
pub fn new( call: impl Into<CallAndMaybeEncoded<Call>>, tx_ext: ExtensionV0, ) -> Result<Self, TransactionValidityError>
Create new SignedPayload for extrinsic format version 4.
This function may fail if implicit of ExtensionV0 is not available.
Sourcepub fn from_raw(
call: impl Into<CallAndMaybeEncoded<Call>>,
tx_ext: ExtensionV0,
implicit: ExtensionV0::Implicit,
) -> Self
pub fn from_raw( call: impl Into<CallAndMaybeEncoded<Call>>, tx_ext: ExtensionV0, implicit: ExtensionV0::Implicit, ) -> Self
Create new SignedPayload from raw components.
Sourcepub fn deconstruct(self) -> (Call, ExtensionV0, ExtensionV0::Implicit)
pub fn deconstruct(self) -> (Call, ExtensionV0, ExtensionV0::Implicit)
Deconstruct the payload into it’s components.