Enum sp_runtime::offchain::HttpRequestStatus
source · pub enum HttpRequestStatus {
DeadlineReached,
IoError,
Invalid,
Finished(u16),
}Expand description
Status of the HTTP request
Variants
DeadlineReached
Deadline was reached while we waited for this request to finish.
Note the deadline is controlled by the calling part, it not necessarily means that the request has timed out.
IoError
An error has occurred during the request, for example a timeout or the remote has closed our socket.
The request is now considered destroyed. To retry the request you need to construct it again.
Invalid
The passed ID is invalid in this context.
Finished(u16)
The request has finished with given status code.