Struct sp_runtime::offchain::http::PendingRequest
source · [−]pub struct PendingRequest {
pub id: RequestId,
}Expand description
A struct representing an uncompleted http request.
Fields
id: RequestIdRequest ID
Implementations
sourceimpl PendingRequest
impl PendingRequest
sourcepub fn wait(self) -> HttpResult
pub fn wait(self) -> HttpResult
Wait for the request to complete.
NOTE this waits for the request indefinitely.
sourcepub fn try_wait(
self,
deadline: impl Into<Option<Timestamp>>
) -> Result<HttpResult, PendingRequest>
pub fn try_wait(
self,
deadline: impl Into<Option<Timestamp>>
) -> Result<HttpResult, PendingRequest>
Attempts to wait for the request to finish,
but will return Err in case the deadline is reached.
sourcepub fn wait_all(requests: Vec<PendingRequest>) -> Vec<HttpResult>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
pub fn wait_all(requests: Vec<PendingRequest>) -> Vec<HttpResult>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
Wait for all provided requests.
sourcepub fn try_wait_all(
requests: Vec<PendingRequest>,
deadline: impl Into<Option<Timestamp>>
) -> Vec<Result<HttpResult, PendingRequest>>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
pub fn try_wait_all(
requests: Vec<PendingRequest>,
deadline: impl Into<Option<Timestamp>>
) -> Vec<Result<HttpResult, PendingRequest>>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
Attempt to wait for all provided requests, but up to given deadline.
Requests that are complete will resolve to an Ok others will return a DeadlineReached
error.