Enum sp_runtime::offchain::storage::MutateStorageError
source · [−]pub enum MutateStorageError<T, E> {
ConcurrentModification(T),
ValueFunctionFailed(E),
}Expand description
Possible errors when mutating a storage value.
Variants
ConcurrentModification(T)
The underlying db failed to update due to a concurrent modification. Contains the new value that was not stored.
ValueFunctionFailed(E)
The function given to us to create the value to be stored failed. May be used to signal that having looked at the existing value, they don’t want to mutate it.