Struct sp_runtime::offchain::storage_lock::StorageLockGuard
source · pub struct StorageLockGuard<'a, 'b, L: Lockable> { /* private fields */ }Expand description
RAII style guard for a lock.
Implementations
sourceimpl<'a, 'b, L: Lockable> StorageLockGuard<'a, 'b, L>
impl<'a, 'b, L: Lockable> StorageLockGuard<'a, 'b, L>
sourcepub fn forget(self)
pub fn forget(self)
Consume the guard but do not unlock the underlying lock.
Can be used to implement a grace period after doing some heavy computations and sending a transaction to be included on-chain. By forgetting the lock, it will stay locked until its expiration deadline is reached while the off-chain worker can already exit.