Struct sp_runtime::offchain::HttpRequestId
source · pub struct HttpRequestId(pub u16);Expand description
Opaque type for offchain http requests.
Tuple Fields
0: u16Trait Implementations
sourceimpl Clone for HttpRequestId
impl Clone for HttpRequestId
sourcefn clone(&self) -> HttpRequestId
fn clone(&self) -> HttpRequestId
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for HttpRequestId
impl Debug for HttpRequestId
sourceimpl Decode for HttpRequestId
impl Decode for HttpRequestId
sourcefn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy
) -> Result<HttpRequestId, Error>where
__CodecInputEdqy: Input,
fn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy
) -> Result<HttpRequestId, Error>where
__CodecInputEdqy: Input,
Attempt to deserialise the value from input.
sourcefn skip<I>(input: &mut I) -> Result<(), Error>where
I: Input,
fn skip<I>(input: &mut I) -> Result<(), Error>where
I: Input,
Attempt to skip the encoded value from input. Read more
sourcefn encoded_fixed_size() -> Option<usize>
fn encoded_fixed_size() -> Option<usize>
Returns the fixed encoded size of the type. Read more
sourceimpl Encode for HttpRequestId
impl Encode for HttpRequestId
sourcefn encode_to<__CodecOutputEdqy>(&self, __codec_dest_edqy: &mut __CodecOutputEdqy)where
__CodecOutputEdqy: Output + ?Sized,
fn encode_to<__CodecOutputEdqy>(&self, __codec_dest_edqy: &mut __CodecOutputEdqy)where
__CodecOutputEdqy: Output + ?Sized,
Convert self to a slice and append it to the destination.
sourcefn using_encoded<R, F>(&self, f: F) -> Rwhere
F: FnOnce(&[u8]) -> R,
fn using_encoded<R, F>(&self, f: F) -> Rwhere
F: FnOnce(&[u8]) -> R,
Convert self to a slice and then invoke the given closure with it.
sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
sourceimpl Hash for HttpRequestId
impl Hash for HttpRequestId
sourceimpl Ord for HttpRequestId
impl Ord for HttpRequestId
sourcefn cmp(&self, other: &HttpRequestId) -> Ordering
fn cmp(&self, other: &HttpRequestId) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 · sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: Sized + PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: Sized + PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<HttpRequestId> for HttpRequestId
impl PartialEq<HttpRequestId> for HttpRequestId
sourcefn eq(&self, other: &HttpRequestId) -> bool
fn eq(&self, other: &HttpRequestId) -> bool
sourceimpl PartialOrd<HttpRequestId> for HttpRequestId
impl PartialOrd<HttpRequestId> for HttpRequestId
sourcefn partial_cmp(&self, other: &HttpRequestId) -> Option<Ordering>
fn partial_cmp(&self, other: &HttpRequestId) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl PassBy for HttpRequestId
impl PassBy for HttpRequestId
type PassBy = Inner<HttpRequestId, u16>
type PassBy = Inner<HttpRequestId, u16>
The strategy that should be used to pass the type.
sourceimpl PassByInner for HttpRequestId
impl PassByInner for HttpRequestId
sourcefn into_inner(self) -> <HttpRequestId as PassByInner>::Inner
fn into_inner(self) -> <HttpRequestId as PassByInner>::Inner
Consumes
self and returns the inner type.sourcefn inner(&self) -> &<HttpRequestId as PassByInner>::Inner
fn inner(&self) -> &<HttpRequestId as PassByInner>::Inner
Returns the reference to the inner type.
sourcefn from_inner(inner: <HttpRequestId as PassByInner>::Inner) -> HttpRequestId
fn from_inner(inner: <HttpRequestId as PassByInner>::Inner) -> HttpRequestId
Construct
Self from the given inner.impl Copy for HttpRequestId
impl EncodeLike<HttpRequestId> for HttpRequestId
impl Eq for HttpRequestId
impl StructuralEq for HttpRequestId
impl StructuralPartialEq for HttpRequestId