Struct sp_runtime::offchain::OpaqueNetworkState
source · pub struct OpaqueNetworkState {
pub peer_id: OpaquePeerId,
pub external_addresses: Vec<OpaqueMultiaddr, Global>,
}Expand description
A blob to hold information about the local node’s network state without committing to its format.
Fields
peer_id: OpaquePeerIdPeerId of the local node in SCALE encoded.
external_addresses: Vec<OpaqueMultiaddr, Global>List of addresses the node knows it can be reached as.