ExtensionPostDispatchWeightHandler

Trait ExtensionPostDispatchWeightHandler 

pub trait ExtensionPostDispatchWeightHandler<DispatchInfo>: RefundWeight {
    // Required method
    fn set_extension_weight(&mut self, info: &DispatchInfo);
}
A type that can handle weight refunds and incorporate extension weights into the call weight after dispatch.

Required Methods

fn set_extension_weight(&mut self, info: &DispatchInfo)

Accrue some weight pertaining to the extension.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ExtensionPostDispatchWeightHandler<()> for ()

Source

fn set_extension_weight(&mut self, _info: &())

Implementors