ExtrinsicCall

Trait ExtrinsicCall 

pub trait ExtrinsicCall: ExtrinsicLike {
    type Call;

    // Required methods
    fn call(&self) -> &Self::Call;
    fn into_call(self) -> Self::Call;
}
An extrinsic on which we can get access to call.

Required Associated Types

type Call

The type of the call.

Required Methods

fn call(&self) -> &Self::Call

Get a reference to the call of the extrinsic.

fn into_call(self) -> Self::Call

Convert the extrinsic into its call.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Address, Call, Signature, ExtensionV0, const MAX_CALL_SIZE: usize, ExtensionOtherVersions> ExtrinsicCall for UncheckedExtrinsic<Address, Call, Signature, ExtensionV0, ExtensionOtherVersions, MAX_CALL_SIZE>

Source

type Call = Call