pub trait TryConvertBack<A, B>: TryConvert<A, B> {
// Required method
fn try_convert_back(b: B) -> Result<A, B>;
}Expand description
Reversing fallible conversion trait which returns the argument in the case of being unable to convert back. Generic over both source and destination types.
Required Methods
Sourcefn try_convert_back(b: B) -> Result<A, B>
fn try_convert_back(b: B) -> Result<A, B>
Attempt to make conversion back. If returning Result::Err, the inner must always be b.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".