MultiVersion

Enum MultiVersion 

pub enum MultiVersion<A = InvalidVersion, B = InvalidVersion, C = InvalidVersion, D = InvalidVersion, E = InvalidVersion, F = InvalidVersion, G = InvalidVersion, H = InvalidVersion, I = InvalidVersion, J = InvalidVersion, K = InvalidVersion, L = InvalidVersion, M = InvalidVersion, N = InvalidVersion, O = InvalidVersion, P = InvalidVersion, Q = InvalidVersion, R = InvalidVersion, S = InvalidVersion, T = InvalidVersion, U = InvalidVersion, V = InvalidVersion, W = InvalidVersion, X = InvalidVersion, Y = InvalidVersion, Z = InvalidVersion> {
Show 26 variants A(A), B(B), C(C), D(D), E(E), F(F), G(G), H(H), I(I), J(J), K(K), L(L), M(M), N(N), O(O), P(P), Q(Q), R(R), S(S), T(T), U(U), V(V), W(W), X(X), Y(Y), Z(Z),
}
An implementation of Pipeline that aggregates multiple versioned transaction extension pipeline.

It is an enum where each variant has its own version, duplicated version must be avoided, only the first used version will be effective other duplicated version will be ignored.

Versioned transaction extension pipelines are configured using the generic parameters.

Example

use sp_runtime::traits::{MultiVersion, PipelineAtVers};

struct PaymentExt;
struct PaymentExtV2;
struct NonceExt;

type ExtV1 = PipelineAtVers<1, (NonceExt, PaymentExt)>;
type ExtV4 = PipelineAtVers<4, (NonceExt, PaymentExtV2)>;

/// The transaction extension pipeline that supports both version 1 and 4.
type TransactionExtension = MultiVersion<ExtV1, ExtV4>;

Variants



A(A)

The transaction extension pipeline of a specific version.



B(B)

The transaction extension pipeline of a specific version.



C(C)

The transaction extension pipeline of a specific version.



D(D)

The transaction extension pipeline of a specific version.



E(E)

The transaction extension pipeline of a specific version.



F(F)

The transaction extension pipeline of a specific version.



G(G)

The transaction extension pipeline of a specific version.



H(H)

The transaction extension pipeline of a specific version.



I(I)

The transaction extension pipeline of a specific version.



J(J)

The transaction extension pipeline of a specific version.



K(K)

The transaction extension pipeline of a specific version.



L(L)

The transaction extension pipeline of a specific version.



M(M)

The transaction extension pipeline of a specific version.



N(N)

The transaction extension pipeline of a specific version.



O(O)

The transaction extension pipeline of a specific version.



P(P)

The transaction extension pipeline of a specific version.



Q(Q)

The transaction extension pipeline of a specific version.



R(R)

The transaction extension pipeline of a specific version.



S(S)

The transaction extension pipeline of a specific version.



T(T)

The transaction extension pipeline of a specific version.



U(U)

The transaction extension pipeline of a specific version.



V(V)

The transaction extension pipeline of a specific version.



W(W)

The transaction extension pipeline of a specific version.



X(X)

The transaction extension pipeline of a specific version.



Y(Y)

The transaction extension pipeline of a specific version.



Z(Z)

The transaction extension pipeline of a specific version.