pub struct PipelineMetadataBuilder {
pub by_version: BTreeMap<u8, Vec<u32>>,
pub in_versions: Vec<TransactionExtensionMetadata>,
}Expand description
A type to build the metadata for the versioned transaction extension pipeline.
Fields
by_version: BTreeMap<u8, Vec<u32>>The transaction extension pipeline by version and its list of items as vec of index into
the other field in_versions.
in_versions: Vec<TransactionExtensionMetadata>The list of all transaction extension item used.
Implementations
Sourceimpl PipelineMetadataBuilder
impl PipelineMetadataBuilder
Sourcepub fn push_versioned_extension(
&mut self,
ext_version: u8,
ext_items: Vec<TransactionExtensionMetadata>,
)
pub fn push_versioned_extension( &mut self, ext_version: u8, ext_items: Vec<TransactionExtensionMetadata>, )
A function to add a versioned transaction extension pipeline to the metadata builder.