Enum sp_runtime::transaction_validity::UnknownTransaction [−][src]
pub enum UnknownTransaction {
CannotLookup,
NoUnsignedValidator,
Custom(u8),
}Expand description
An unknown transaction validity.
Variants
Could not lookup some information that is required to validate the transaction.
No validator found for the given unsigned transaction.
Custom(u8)Any other custom unknown validity that is not covered by this enum.
Tuple Fields of Custom
0: u8Trait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Performs the conversion.
Performs the conversion.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.