Struct sp_runtime::biguint::BigUint
source · [−]pub struct BigUint { /* private fields */ }Expand description
Simple wrapper around an infinitely large integer, represented as limbs of Single.
Implementations
sourceimpl BigUint
impl BigUint
sourcepub fn with_capacity(size: usize) -> BigUint
pub fn with_capacity(size: usize) -> BigUint
Create a new instance with size limbs. This prevents any number with zero limbs to be
created.
The behavior of the type is undefined with zero limbs.
sourcepub fn from_limbs(limbs: &[u32]) -> BigUint
pub fn from_limbs(limbs: &[u32]) -> BigUint
Raw constructor from custom limbs. If limbs is empty, Zero::zero() implementation is
used.
sourcepub fn get(&self, index: usize) -> u32
pub fn get(&self, index: usize) -> u32
A naive getter for limb at index. Note that the order is lsb -> msb.
Panics
This panics if index is out of range.
sourcepub fn checked_get(&self, index: usize) -> Option<u32>
pub fn checked_get(&self, index: usize) -> Option<u32>
A naive getter for limb at index. Note that the order is lsb -> msb.
sourcepub fn set(&mut self, index: usize, value: u32)
pub fn set(&mut self, index: usize, value: u32)
A naive setter for limb at index. Note that the order is lsb -> msb.
Panics
This panics if index is out of range.
sourcepub fn lsb(&self) -> u32
pub fn lsb(&self) -> u32
returns the least significant limb of the number.
Panics
While the constructor of the type prevents this, this can panic if self has no digits.
sourcepub fn msb(&self) -> u32
pub fn msb(&self) -> u32
returns the most significant limb of the number.
Panics
While the constructor of the type prevents this, this can panic if self has no digits.
sourcepub fn lstrip(&mut self)
pub fn lstrip(&mut self)
Strips zeros from the left side (the most significant limbs) of self, if any.
sourcepub fn lpad(&mut self, size: usize)
pub fn lpad(&mut self, size: usize)
Zero-pad self from left to reach size limbs. Will not make any difference if self
is already bigger than size limbs.
sourcepub fn add(self, other: &BigUint) -> BigUint
pub fn add(self, other: &BigUint) -> BigUint
Adds self with other. self and other do not have to have any particular size. Given
that the n = max{size(self), size(other)}, it will produce a number with n + 1
limbs.
This function does not strip the output and returns the original allocated n + 1
limbs. The caller may strip the output if desired.
Taken from “The Art of Computer Programming” by D.E. Knuth, vol 2, chapter 4.
sourcepub fn sub(self, other: &BigUint) -> Result<BigUint, BigUint>
pub fn sub(self, other: &BigUint) -> Result<BigUint, BigUint>
Subtracts other from self. self and other do not have to have any particular size.
Given that the n = max{size(self), size(other)}, it will produce a number of size n.
If other is bigger than self, Err(B - borrow) is returned.
Taken from “The Art of Computer Programming” by D.E. Knuth, vol 2, chapter 4.
sourcepub fn mul(self, other: &BigUint) -> BigUint
pub fn mul(self, other: &BigUint) -> BigUint
Multiplies n-limb number self with m-limb number other.
The resulting number will always have n + m limbs.
This function does not strip the output and returns the original allocated n + m
limbs. The caller may strip the output if desired.
Taken from “The Art of Computer Programming” by D.E. Knuth, vol 2, chapter 4.
sourcepub fn div_unit(self, other: u32) -> BigUint
pub fn div_unit(self, other: u32) -> BigUint
Divides self by a single limb other. This can be used in cases where the original
division cannot work due to the divisor (other) being just one limb.
Invariant: other cannot be zero.
sourcepub fn div(self, other: &BigUint, rem: bool) -> Option<(BigUint, BigUint)>
pub fn div(self, other: &BigUint, rem: bool) -> Option<(BigUint, BigUint)>
Divides an n + m limb self by a n limb other. The result is a m + 1 limb
quotient and a n limb remainder, if enabled by passing true in rem argument, both
in the form of an option’s Ok.
- requires
otherto be stripped and have no leading zeros. - requires
selfto be stripped and have no leading zeros. - requires
otherto have at least two limbs. - requires
selfto have a greater length compared toother.
All arguments are examined without being stripped for the above conditions. If any of
the above fails, None is returned.`
Taken from “The Art of Computer Programming” by D.E. Knuth, vol 2, chapter 4.