ExtrinsicFormat

Enum ExtrinsicFormat 

pub enum ExtrinsicFormat<AccountId, ExtensionV0, ExtensionOtherVersions = InvalidVersion> {
    Bare,
    Signed(AccountId, ExtensionV0),
    General(ExtensionVariant<ExtensionV0, ExtensionOtherVersions>),
}
The kind of extrinsic this is, including any fields required of that kind. This is basically the full extrinsic except the Call.

Bare extrinsics and signed extrinsics are extended with the transaction extension version 0, specified by the generic parameter ExtensionV0.

General extrinsics support multiple transaction extension version, specified by both ExtensionV0 and ExtensionOtherVersions, by default ExtensionOtherVersions is set to invalid version, making ExtensionV0 the only supported version. If you want to support more versions, you need to specify the ExtensionOtherVersions parameter.

Variants



Bare

Extrinsic is bare; it must pass either the bare forms of TransactionExtension or ValidateUnsigned, both deprecated, or alternatively a ProvideInherent.



Signed(AccountId, ExtensionV0)

Extrinsic has a default Origin of Signed(AccountId) and must pass all TransactionExtensions regular checks and includes all extension data.



General(ExtensionVariant<ExtensionV0, ExtensionOtherVersions>)

Extrinsic has a default Origin of None and must pass all TransactionExtensions. regular checks and includes all extension data.