Struct sp_runtime::generic::SignedPayload
source · pub struct SignedPayload<Call, Extra: SignedExtension>(_);Expand description
A payload that has been signed for an unchecked extrinsics.
Note that the payload that we sign to produce unchecked extrinsic signature
is going to be different than the SignaturePayload - so the thing the extrinsic
actually contains.
Implementations
sourceimpl<Call, Extra> SignedPayload<Call, Extra>where
Call: Encode,
Extra: SignedExtension,
impl<Call, Extra> SignedPayload<Call, Extra>where
Call: Encode,
Extra: SignedExtension,
sourcepub fn new(call: Call, extra: Extra) -> Result<Self, TransactionValidityError>
pub fn new(call: Call, extra: Extra) -> Result<Self, TransactionValidityError>
Create new SignedPayload.
This function may fail if additional_signed of Extra is not available.
sourcepub fn from_raw(
call: Call,
extra: Extra,
additional_signed: Extra::AdditionalSigned
) -> Self
pub fn from_raw(
call: Call,
extra: Extra,
additional_signed: Extra::AdditionalSigned
) -> Self
Create new SignedPayload from raw components.
sourcepub fn deconstruct(self) -> (Call, Extra, Extra::AdditionalSigned)
pub fn deconstruct(self) -> (Call, Extra, Extra::AdditionalSigned)
Deconstruct the payload into it’s components.