Struct sp_runtime::offchain::Capabilities
source · pub struct Capabilities { /* private fields */ }Expand description
Execution context extra capabilities.
Implementations
sourceimpl Capabilities
impl Capabilities
sourcepub const TRANSACTION_POOL: Capabilities = Self{ bits: 1,}
pub const TRANSACTION_POOL: Capabilities = Self{ bits: 1,}
Access to transaction pool.
sourcepub const HTTP: Capabilities = Self{ bits: 2,}
pub const HTTP: Capabilities = Self{ bits: 2,}
External http calls.
sourcepub const KEYSTORE: Capabilities = Self{ bits: 4,}
pub const KEYSTORE: Capabilities = Self{ bits: 4,}
Keystore access.
sourcepub const RANDOMNESS: Capabilities = Self{ bits: 8,}
pub const RANDOMNESS: Capabilities = Self{ bits: 8,}
Randomness source.
sourcepub const NETWORK_STATE: Capabilities = Self{ bits: 16,}
pub const NETWORK_STATE: Capabilities = Self{ bits: 16,}
Access to opaque network state.
sourcepub const OFFCHAIN_DB_READ: Capabilities = Self{ bits: 32,}
pub const OFFCHAIN_DB_READ: Capabilities = Self{ bits: 32,}
Access to offchain worker DB (read only).
sourcepub const OFFCHAIN_DB_WRITE: Capabilities = Self{ bits: 64,}
pub const OFFCHAIN_DB_WRITE: Capabilities = Self{ bits: 64,}
Access to offchain worker DB (writes).
sourcepub const NODE_AUTHORIZATION: Capabilities = Self{ bits: 128,}
pub const NODE_AUTHORIZATION: Capabilities = Self{ bits: 128,}
Manage the authorized nodes
sourcepub const TIME: Capabilities = Self{ bits: 256,}
pub const TIME: Capabilities = Self{ bits: 256,}
Access time related functionality
sourcepub const fn empty() -> Capabilities
pub const fn empty() -> Capabilities
Returns an empty set of flags.
sourcepub const fn all() -> Capabilities
pub const fn all() -> Capabilities
Returns the set containing all flags.
sourcepub const fn from_bits(bits: u32) -> Option<Capabilities>
pub const fn from_bits(bits: u32) -> Option<Capabilities>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> Capabilities
pub const fn from_bits_truncate(bits: u32) -> Capabilities
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> Capabilities
pub const unsafe fn from_bits_unchecked(bits: u32) -> Capabilities
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: Capabilities) -> bool
pub const fn intersects(&self, other: Capabilities) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: Capabilities) -> bool
pub const fn contains(&self, other: Capabilities) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: Capabilities)
pub fn insert(&mut self, other: Capabilities)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: Capabilities)
pub fn remove(&mut self, other: Capabilities)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: Capabilities)
pub fn toggle(&mut self, other: Capabilities)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: Capabilities, value: bool)
pub fn set(&mut self, other: Capabilities, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: Capabilities) -> Capabilities
pub const fn intersection(self, other: Capabilities) -> Capabilities
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: Capabilities) -> Capabilities
pub const fn union(self, other: Capabilities) -> Capabilities
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: Capabilities) -> Capabilities
pub const fn difference(self, other: Capabilities) -> Capabilities
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: Capabilities) -> Capabilities
pub const fn symmetric_difference(self, other: Capabilities) -> Capabilities
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> Capabilities
pub const fn complement(self) -> Capabilities
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.
sourceimpl Capabilities
impl Capabilities
sourcepub fn rich_offchain_call() -> Capabilities
pub fn rich_offchain_call() -> Capabilities
Return capabilities for rich offchain calls.
Those calls should be allowed to sign and submit transactions and access offchain workers database (but read only!).