ExtrinsicMetadata

Trait ExtrinsicMetadata 

pub trait ExtrinsicMetadata {
    type TransactionExtensionPipelines;

    const VERSIONS: &'static [u8];
}
Implementor is an Extrinsic and provides metadata about this extrinsic.

Required Associated Constants

const VERSIONS: &'static [u8]

The format versions of the Extrinsic.

By format we mean the encoded representation of the Extrinsic.

Required Associated Types

type TransactionExtensionPipelines

All version of transaction extensions attached to this Extrinsic.

For extrinsic version 4, extrinsics don’t specify any version, the pipeline version 0 is used. For extrinsic version 5, bare extrinsics don’t specify any version, the pipeline version 0 is used.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<Address, Call: Dispatchable, Signature, ExtensionV0, const MAX_CALL_SIZE: usize, ExtensionOtherVersions> ExtrinsicMetadata for UncheckedExtrinsic<Address, Call, Signature, ExtensionV0, ExtensionOtherVersions, MAX_CALL_SIZE>

Source

const VERSIONS: &'static [u8]

Source

type TransactionExtensionPipelines = ExtensionVariant<ExtensionV0, ExtensionOtherVersions>