SignaturePayload

Trait SignaturePayload 

pub trait SignaturePayload {
    type SignatureAddress: TypeInfo;
    type Signature: TypeInfo;
    type SignatureExtra: TypeInfo;
}
Something that acts like a SignaturePayload of an Extrinsic.

Required Associated Types

type SignatureAddress: TypeInfo

The type of the address that signed the extrinsic.

Particular to a signed extrinsic.

type Signature: TypeInfo

The signature type of the extrinsic.

Particular to a signed extrinsic.

type SignatureExtra: TypeInfo

The additional data that is specific to the signed extrinsic.

Particular to a signed extrinsic.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl SignaturePayload for ()

Implementors

Source

impl<Address: TypeInfo, Signature: TypeInfo, Extension: TypeInfo> SignaturePayload for UncheckedSignaturePayload<Address, Signature, Extension>

Source

type SignatureAddress = Address

Source

type Signature = Signature

Source

type SignatureExtra = Extension