[−][src]Trait sp_runtime::traits::Zero
Required methods
fn zero() -> Self
Returns the additive identity element of Self, 0.
Purity
This function should return the same result at all times regardless of
external mutable state, for example values stored in TLS or in
static muts.
fn is_zero(&self) -> bool
Returns true if self is equal to the additive identity.
Provided methods
fn set_zero(&mut self)
Sets self to the additive identity element of Self, 0.
Implementations on Foreign Types
impl<T> Zero for Ratio<T> where
T: Clone + Integer, [src]
T: Clone + Integer,
impl Zero for BigUint[src]
impl Zero for BigInt[src]
impl Zero for f64[src]
impl Zero for u128[src]
impl Zero for i8[src]
impl Zero for i64[src]
impl<T> Zero for Wrapping<T> where
T: Zero,
Wrapping<T>: Add<Wrapping<T>>,
<Wrapping<T> as Add<Wrapping<T>>>::Output == Wrapping<T>, [src]
T: Zero,
Wrapping<T>: Add<Wrapping<T>>,
<Wrapping<T> as Add<Wrapping<T>>>::Output == Wrapping<T>,