Module vers_tx_ext

Module vers_tx_ext 

The traits and primitive types for versioned transaction extension pipelines.

Structs

PipelineAtVers
A transaction extension pipeline defined for a single version.
PipelineMetadataBuilder
A type to build the metadata for the versioned transaction extension pipeline.

Enums

ExtensionVariant
A versioned transaction extension pipeline defined with 2 variants: one for the version 0 and one for other versions.
InvalidVersion
An implementation of Pipeline that consider any version invalid.
MultiVersion
An implementation of Pipeline that aggregates multiple versioned transaction extension pipeline.

Traits

DecodeWithVersion
A type that can be decoded from a specific version and a codec::Input.
DecodeWithVersionWithMemTracking
A type implements DecodeWithVersion where inner decoding is implementing codec::DecodeWithMemTracking.
Pipeline
A versioned transaction extension pipeline.
PipelineVersion
The version for an instance of a versioned transaction extension pipeline.