The traits and primitive types for versioned transaction extension pipelines.
Structs
- Pipeline
AtVers - A transaction extension pipeline defined for a single version.
- Pipeline
Metadata Builder - A type to build the metadata for the versioned transaction extension pipeline.
Enums
- Extension
Variant - A versioned transaction extension pipeline defined with 2 variants: one for the version 0 and one for other versions.
- Invalid
Version - An implementation of
Pipelinethat consider any version invalid. - Multi
Version - An implementation of
Pipelinethat aggregates multiple versioned transaction extension pipeline.
Traits
- Decode
With Version - A type that can be decoded from a specific version and a
codec::Input. - Decode
With Version With MemTracking - A type implements
DecodeWithVersionwhere inner decoding is implementingcodec::DecodeWithMemTracking. - Pipeline
- A versioned transaction extension pipeline.
- Pipeline
Version - The version for an instance of a versioned transaction extension pipeline.