pub struct ValidTransactionBuilder { /* private fields */ }Expand description
ValidTransaction builder.
Allows to easily construct ValidTransaction and most importantly takes care of
prefixing requires and provides tags to avoid conflicts.
Implementations
sourceimpl ValidTransactionBuilder
impl ValidTransactionBuilder
sourcepub fn priority(self, priority: TransactionPriority) -> Self
pub fn priority(self, priority: TransactionPriority) -> Self
Set the priority of a transaction.
Note that the final priority for FRAME is combined from all SignedExtensions.
Most likely for unsigned transactions you want the priority to be higher
than for regular transactions. We recommend exposing a base priority for unsigned
transactions as a runtime module parameter, so that the runtime can tune inter-module
priorities.
sourcepub fn longevity(self, longevity: TransactionLongevity) -> Self
pub fn longevity(self, longevity: TransactionLongevity) -> Self
Set the longevity of a transaction.
By default the transaction will be considered valid forever and will not be revalidated by the transaction pool. It’s recommended though to set the longevity to a finite value though. If unsure, it’s also reasonable to expose this parameter via module configuration and let the runtime decide.
sourcepub fn propagate(self, propagate: bool) -> Self
pub fn propagate(self, propagate: bool) -> Self
Set the propagate flag.
Set to false if the transaction is not meant to be gossiped to peers. Combined with
TransactionSource::Local validation it can be used to have special kind of
transactions that are only produced and included by the validator nodes.
sourcepub fn and_requires(self, tag: impl Encode) -> Self
pub fn and_requires(self, tag: impl Encode) -> Self
Add a TransactionTag to the set of required tags.
The tag will be encoded and prefixed with module prefix (if any).
If you’d rather add a raw require tag, consider using #combine_with method.
sourcepub fn and_provides(self, tag: impl Encode) -> Self
pub fn and_provides(self, tag: impl Encode) -> Self
Add a TransactionTag to the set of provided tags.
The tag will be encoded and prefixed with module prefix (if any).
If you’d rather add a raw require tag, consider using #combine_with method.
sourcepub fn combine_with(self, validity: ValidTransaction) -> Self
pub fn combine_with(self, validity: ValidTransaction) -> Self
Augment the builder with existing ValidTransaction.
This method does add the prefix to require or provides tags.
sourcepub fn build(self) -> TransactionValidity
pub fn build(self) -> TransactionValidity
Finalize the builder and produce TransactionValidity.
Note the result will always be Ok. Use Into to produce ValidTransaction.